@@ -13,11 +13,11 @@ use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/VCS::Which::Plugin/;
-use Path::Class;
+use Path::Tiny;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.5.5');
+our $VERSION = version->new('0.5.6');
 our $name    = 'Subversion';
 our $exe     = 'svn';
 our $meta    = '.svn';
@@ -40,7 +40,7 @@ sub used {
     my ( $self, $dir ) = @_;
 
     if (-f $dir) {
-        $dir = file($dir)->parent;
+        $dir = path($dir)->parent;
     }
 
     croak "$dir is not a directory!" if !-d $dir;
@@ -138,7 +138,7 @@ sub log {
 sub versions {
     my ($self, $file, $oldest, $newest, $max) = @_;
 
-    $file = file($file);
+    $file = path($file);
     local $CWD = -d $file ? $file : $file->parent;
     my %logs = %{ $self->log(-d $file ? '.' : $file->basename, $max ? "--limit $max" : '') };
     my @versions;
@@ -160,7 +160,7 @@ VCS::Which::Plugin::Subversion - The Subversion plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Subversion version 0.5.5.
+This documentation refers to VCS::Which::Plugin::Subversion version 0.5.6.
 
 =head1 SYNOPSIS
 
